from django import template

register = template.Library()


@register.filter(name='get_color')
def get_color(value):
    value = str(value)
    if value=='high':
        return 'red'
    if value=='avg':
        return 'orange'
    if value=='low':
        return 'green'



from django import template

register = template.Library()


@register.filter(name='how_many_is_in_cart')
def how_many_is_in_cart(product, cart):
    product_id=str(product.id) # چون عدد هست و اینت. در حالی که ما اون ور استرینگ ذخیره کرده بودیم.
    cart_info = cart.cart # تو کارت رکوئست و سشن و کارت رو ذخیره کرده بودیم که الان فقط با کارتش که دیکشنری هست کار دارم.
    if product_id in cart: # چون تابع داندر کانتین رو برای خود کلاس کارت نوشتم، روی یه نمونه از کلاس کارت میتونم از اپراتور این استفاده کنم. اگه تابع داندر کانتین رو ننویسیم پایتون میره سراغ ایتر و خلاصه مشکل داشت اینجا که نوشتمش. جالب و ساده هم بود.
        quantity = cart_info.get(product_id).get('quantity')
        return quantity
    # if product_id in cart_info: # البته تست کردم رو کارت اینفو هم از اپراتور این استفاده کردم کار میکرد. چون یه دیکشنری هست و خود دیکشنری ها دارن این ویژگی رو. به هر حال چون چیز جالبی بود و تازه یاد گرفتم گذاشتم که باشه همون بالاییه. در حالی که اگه اون رو بردارم میتونم تو کلاس کارت تابع داندر کانتینز رو حذف کنم.
    return 0
    



from django import template

register = template.Library()


@register.filter(name='times') 
def times(number):
    if number==None:
        number=0
    return range(number)


@register.filter
def get_n_first_objects(query, n=5):
    return query[:n]


@register.filter
def get_n_last_objects(query, n=5):
    length = len(query)
    if length>n:
        return query[length-n:]
    return query



from django import template

register = template.Library()


WEEKDAYS = {
    'Sat': 'شنبه',
    'Sun': 'یکشنبه',
    'Mon': 'دوشنبه',
    'Tue': 'سه‌شنبه', # بین سه و شنبه از نیم فاصله استفاده شده
    'Wed': 'چهارشنبه',
    'Thu': 'پنجشنبه',
    'Fri': 'جمعه',
}


@register.filter(name='pn')
def persian_numbers_int(value):
    value = str(value)
    english_to_persian_table = value.maketrans('0123456789', '۰۱۲۳۴۵۶۷۸۹')
    return value.translate(english_to_persian_table)


@register.filter(name='pnf')
def persian_numbers_float(value):
    value = str(value)
    english_to_persian_table = value.maketrans('0123456789.', '۰۱۲۳۴۵۶۷۸۹/')
    return value.translate(english_to_persian_table)


@register.filter(name='cspn')
def comma_separated_persian_numbers(value, separator=3):
    try:
        s = int(separator)
        separator = s if s>0 else 3
    except ValueError:
        separator = 3
    value = str(value)
    value = value.replace(' ', '')
    value = value.replace(',', '')
    value = value.replace('_', '')
    if len(value)==0:
        raise ValueError("The parameter you sent is empty!")
    for digit in value:
        if digit not in '0123456789۰۱۲۳۴۵۶۷۸۹.':
            raise ValueError("The parameter you sent is not a real number!"
            "Check special characters like '.', ',', '_', '/', '÷' and ..."
            " in sent number!")
    res = ''
    for i, char in enumerate(value[::-1]):
        res += char
        if i%separator==separator-1:
            res+=','
    if i%separator==separator-1:
        value = res[-2::-1]
    else:
        value = res[::-1]
    table = value.maketrans('0123456789', '۰۱۲۳۴۵۶۷۸۹')
    return value.translate(table)


@register.filter(name='p_weekday')
def persian_weekday(value):
    day = str(value).capitalize()[:3]
    return WEEKDAYS.get(day, 'روز نامشخص از هفته')



from string import ascii_letters
from django import template

register = template.Library()


@register.filter(name='has_english_letter')
def has_english_letter(word: str):
    for char in word:
        if char in ascii_letters:
            return True
    return False    
